The mplcursors API
==================

.. module:: mplcursors

|

.. autosummary::
   Cursor
   cursor
   HoverMode
   Selection
   compute_pick
   get_ann_text
   move
   make_highlight

|

.. autoclass:: Cursor
   :members:
   :special-members: __init__
   :undoc-members:

.. autofunction:: cursor

.. autoclass:: HoverMode
   :members:
   :undoc-members:

.. autoclass:: Selection
   :members:
   :undoc-members:

.. autofunction:: compute_pick
.. autofunction:: get_ann_text
.. autofunction:: move
.. autofunction:: make_highlight
